#
# spec file for package plasma-nm5
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
%define mm_support 1
Name:           plasma-nm5
Version:        5.27.11
Release:        bp156.1.1
Summary:        Plasma applet written in QML for managing network connections
License:        (GPL-2.0-only OR GPL-3.0-only) AND (LGPL-2.1-only OR LGPL-3.0-only)
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/plasma-nm-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-nm-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  NetworkManager-devel >= 0.9.8.4
BuildRequires:  extra-cmake-modules >= 1.3.0
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  mobile-broadband-provider-info
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Completion) >= 5.98.0
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5Init)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KDELibs4Support)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5Service)
BuildRequires:  cmake(KF5Solid)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qca-qt5) >= 2.1.0
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5UiTools)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(openconnect) >= 5.2
Requires:       NetworkManager
Requires:       kded
Requires:       kirigami2
Requires:       kwalletd5
Requires:       prison-qt5-imports
Recommends:     mobile-broadband-provider-info
Provides:       NetworkManager-client
Provides:       plasma-nm-kf5 = %{version}
Obsoletes:      plasma-nm-kf5 < %{version}
# Merged into the core in 5.15.80
Provides:       %{name}-wireguard = %{version}
Obsoletes:      %{name}-wireguard < %{version}
Provides:       plasma-nm = %{version}
Obsoletes:      plasma-nm < %{version}
%if 0%{?mm_support}
BuildRequires:  cmake(KF5ModemManagerQt)
BuildRequires:  pkgconfig(ModemManager) >= 1.0.0
%endif
Obsoletes:      NetworkManager-kde4-devel
Obsoletes:      NetworkManager-kde4-libs
Obsoletes:      NetworkManager-kde4-libs-lang
Obsoletes:      NetworkManager-novellvpn-kde4
Obsoletes:      plasmoid-networkmanagement
Supplements:    packageand(plasma5-desktop:NetworkManager)

%description
Plasma applet for controlling network connections on systems
that use the NetworkManager service.

%package openvpn
Summary:        OpenVPN support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-openvpn
Supplements:    packageand(%{name}:NetworkManager-openvpn)
Provides:       NetworkManager-openvpn-frontend
Provides:       plasma-nm-openvpn = %{version}
Obsoletes:      NetworkManager-openvpn-kde4
Obsoletes:      plasma-nm-openvpn < %{version}

%description openvpn
OpenVPN plugin for plasma-nm components.

%package vpnc
Summary:        vpnc support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-vpnc
Supplements:    packageand(%{name}:NetworkManager-vpnc)
Provides:       NetworkManager-vpnc-frontend
Provides:       plasma-nm-vpnc = %{version}
Obsoletes:      NetworkManager-vpnc-kde4
Obsoletes:      plasma-nm-vpnc < %{version}

%description vpnc
vpnc plugin for plasma-nm components.

%package openconnect
Summary:        OpenConnect support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-openconnect
Requires:       openconnect
Supplements:    packageand(%{name}:NetworkManager-openconnect)
Provides:       NetworkManager-openconnect-frontend
Provides:       plasma-nm-openconnect = %{version}
Obsoletes:      NetworkManager-openconnect-kde4
Obsoletes:      plasma-nm-openconnect < %{version}

%description openconnect
OpenConnect plugin for plasma-nm components.

%package libreswan
Summary:        Libreswan support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-libreswan
Supplements:    packageand(%{name}:NetworkManager-libreswan)
Provides:       NetworkManager-libreswan-frontend
# Old names
Provides:       plasma-nm-openswan = %{version}
Obsoletes:      plasma-nm-openswan < %{version}
Provides:       %{name}-openswan = %{version}
Obsoletes:      %{name}-openswan < %{version}

%description libreswan
Libreswan plugin for plasma-nm components.

%package strongswan
Summary:        strongSwan support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-strongswan
Supplements:    packageand(%{name}:NetworkManager-strongswan)
Provides:       NetworkManager-strongswan-frontend
Provides:       plasma-nm-strongswan = %{version}
Obsoletes:      plasma-nm-strongswan < %{version}

%description strongswan
strongSwan plugin for plasma-nm components.

%package l2tp
Summary:        L2TP support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-l2tp
Supplements:    packageand(%{name}:NetworkManager-l2tp)
Provides:       NetworkManager-l2tp-frontend
Provides:       plasma-nm-l2tp = %{version}
Obsoletes:      plasma-nm-l2tp < %{version}

%description l2tp
Layer Two Tunneling Protocol (L2TP) plugin for plasma-nm components.

%package pptp
Summary:        PPTP support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-pptp
Supplements:    packageand(%{name}:NetworkManager-pptp)
Provides:       NetworkManager-pptp-frontend
Provides:       plasma-nm-pptp = %{version}
Obsoletes:      NetworkManager-pptp-kde4
Obsoletes:      plasma-nm-pptp < %{version}

%description pptp
Point-To-Point Tunneling Protocol (PPTP) plugin for plasma-nm components.

%package ssh
Summary:        SSH support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
# NetworkManager-ssh doesn't exist in Factory
#Requires:       NetworkManager-ssh
Supplements:    packageand(%{name}:NetworkManager-ssh)
Provides:       NetworkManager-ssh-frontend

%description ssh
Secure Shell (SSH) plugin for plasma-nm components.

%package sstp
Summary:        SSTP support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
# NetworkManager-sstp doesn't exist in Factory
#Requires:       NetworkManager-sstp
Supplements:    packageand(%{name}:NetworkManager-sstp)
Provides:       NetworkManager-sstp-frontend

%description sstp
Secure Sockets Tunneling Protocol (SSTP) plugin for plasma-nm components.

%package iodine
Summary:        VPN support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires:       NetworkManager-iodine
Supplements:    packageand(%{name}:NetworkManager-iodine)
Provides:       NetworkManager-iodine-frontend

%description iodine
Iodine (VPN through DNS tunnel) plugin for plasma-nm components.

%package fortisslvpn
Summary:        FortiGate SSL VPN support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
# Not available in oS:F stagings, leading to installcheck failure
# Requires:       NetworkManager-fortisslvpn
Supplements:    packageand(%{name}:NetworkManager-fortisslvpn)
Provides:       NetworkManager-fortisslvpn-frontend

%description fortisslvpn
FortiGate SSL VPN plugin for plasma-nm components.

%package mobile
Summary:        Mobile settings support for %{name}
Group:          System/GUI/KDE
Requires:       %{name} = %{version}

%description mobile
KConfig Modules and applets for
wireless connectivity on Plasma Mobile.

%lang_package

%prep
%autosetup -p1 -n plasma-nm-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir} -DBUILD_MOBILE=ON
%cmake_build

%install
%kf5_makeinstall -C build

%kf5_find_lang

%fdupes %{buildroot}

%files
%license LICENSES/*
%{_kf5_applicationsdir}/kcm_networkmanagement.desktop
%{_kf5_libdir}/libplasmanm_editor.so
%{_kf5_libdir}/libplasmanm_internal.so
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kded
%{_kf5_plugindir}/kf5/kded/networkmanagement.so
%dir %{_kf5_plugindir}/plasma/network
%dir %{_kf5_plugindir}/plasma/network/vpn
%dir %{_kf5_plugindir}/plasma/kcms
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets
%{_kf5_qmldir}/
%{_kf5_notifydir}/
%{_kf5_sharedir}/plasma/
%dir %{_kf5_appstreamdir}
%{_kf5_appstreamdir}/org.kde.plasma.networkmanagement.appdata.xml
%{_kf5_plugindir}/plasma/kcms/systemsettings_qwidgets/kcm_networkmanagement.so
%{_kf5_debugdir}/plasma-nm.categories
%{_datadir}/kcm_networkmanagement/

%files openvpn
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/*_openvpnui.so

%files vpnc
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/*_vpncui.so

%files openconnect
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_anyconnect.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_globalprotectui.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_juniperui.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_pulseui.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_arrayui.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_f5ui.so
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_openconnect_fortinetui.so

%files libreswan
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_libreswanui.so

%files strongswan
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_strongswanui.so

%files l2tp
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_l2tpui.so

%files pptp
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_pptpui.so

%files ssh
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_sshui.so

%files sstp
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_sstpui.so

%files iodine
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_iodineui.so

%files fortisslvpn
%license LICENSES/*
%{_kf5_plugindir}/plasma/network/vpn/plasmanetworkmanagement_fortisslvpnui.so

%files mobile
%license LICENSES/*
%dir %{_kf5_plugindir}/kcms/
%{_kf5_plugindir}/kcms/kcm_mobile_hotspot.so
%{_kf5_plugindir}/kcms/kcm_mobile_wifi.so
%dir %{_kf5_sharedir}/kpackage/
%dir %{_kf5_sharedir}/kpackage/kcms/
%{_kf5_sharedir}/kpackage/kcms/kcm_mobile_hotspot/
%{_kf5_sharedir}/kpackage/kcms/kcm_mobile_wifi/

%files lang -f %{name}.lang

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- No code changes since 5.27.10
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- Changes since 5.27.9:
  * Adapt to plasma-framework being renamed to libplasma
  * Adapt to plasma-framework moving to Plasma
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- Changes since 5.27.8:
  * Revert "Don't force active dialogs right after showing"
  * [libreswan] should save even when group name is empty.
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- No code changes since 5.27.7
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- Changes since 5.27.6:
  * Avoid double delete of TabWidget
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- Changes since 5.27.4:
  * Use nm_conn_wireguard_import to import WireGuard files (kde#420066,kde#468365,kde#452952,kde#423973,kde#427222)
  * Persist imported VPN connections on disk (kde#468666)
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Changes since 5.27.2:
  * Don't crash when importing VPN config with missing NetworkManager plugin (kde#465484)
  * [kcm] Show VPN import error in the UI
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * Guard against double instantiation or double-free of PlasmaNM.NetworkModel (kde#465805)
  * Filter out the loopback device (kde#465655)
  * Revert "Use QWindow instead of KWindowSystem to set KeepAbove" (kde#465751)
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * Don't initialize sent/received bytes with stale values
  * applet: Fix key navigation in standalone (non-systray) mode
  * applet: Only show airplane mode in context menu when visible in toolbar (kde#464527)
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Too many changes to list here
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- Changes since 5.26.4:
  * Fix connecting to WPA3-personal networks
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- Changes since 5.26.3:
  * Show current MAC for wired connections
  * Show current MAC address instead of permanent MAC address in details view (kde#456119)
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- Changes since 5.26.2:
  * L2TP: Fix detection of Libreswan 4.9 and later
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- Changes since 5.26.0:
  * applet: add missing left padding on toolbar (kde#458742)
  * applet: Fix enabled states of Wi-Fi and WWAN checkboxes in Edit Mode
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * applet: Clean up model delaying in list delegate's destructor
  * applet: Rename Handler's signal isScanningChanged
  * applet: Provide visual indication when scanning Wi-Fi networks
  * applet: Fix delayModelUpdates mode (kde#389052)
  * applet: Block all role changes while in delayModelUpdates mode
  * applet: Fix airplane mode binding in scan timer
  * applet: Bind `enabled` state of "Connect" action reliably
  * Fix .nospace() punctuation in logs
  * Install po folder
  * [kcm] Set KLocalizedContext for QQuickWidget (kde#459229)
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Too many changes to list here
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- Changes since 5.25.1:
  * applet: add keyboard navigation in QR window
  * applet" Fix showing network QR code button only for WiFi networks (kde#454643,kde#453806)
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- Changes since 5.24.90:
  * Add xdg activation support to captive portal notification
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Too many changes to list here
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- Changes since 5.24.4:
  * Don't use forceActiveFocus to focus the applet toolbar
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- Changes since 5.24.1:
  * kded: don't show "connection activated" notifications on launch/login (kde#399973)
  * Don't use warning icon in notification when the user disconnects a VPN
  * Use error icon for missing VPN plugin notification
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * Applet: Check if we have Kirigami.InputMethod for search field focus
  * Applet: Correct willShowOnActive check for search field
  * Only focus search field by default if that doesn't show a virtual keyboard
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Too many changes to list here
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Fri Dec 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix package build with plasma-framework 5.89.0.
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- Changes since 5.23.2:
  * OpenVPN: fix logic in auth dialog (kde#444882)
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- Changes since 5.23.1:
  * Set Qt.ImhNoPredictiveText for text field that acts as a search field
  * openconnect: Adjust version check in CMake and allow version 3.99 again
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- Changes since 5.23.0:
  * openconnect: Adjust version check in CMake and allow version 3.99 again
  * openconnect widget: Default to "anyconnect" when protocol is not set.
  * openconnect: Make FSID passphrase + empty private key combination work. (kde#443770)
  * Only include mobileproviderstest with ModemManager
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Remove applet list item animations
- Add new key + signature to plasma.keyring
* Sat Sep 25 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Drop hard requirement on NM-fortisslvpn for now to avoid
  installcheck failure in staging
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Too many changes to list here
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- Changes since 5.22.0:
  * Add missing QFile include
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Do not store passwords to KWallet on live images
  * Prevent showing wrong speeds on initial open (kde#420365)
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * Add missing QQueue include
  * Make the configuration the canonical source for airplaneModeEnabled
  * Create an instance of Configuration per QML engine
  * Add NOTIFY to airplaneModeEnabled
  * [applet/contents/ui/ConnectionItem] Fix trying to reach non existing objects
  * Forward opeconnect usergroup (kde#435561)
  * [desktop kcm] Use standard Kirigami.ListSectionHeader
  * Set "font:" not "font.pointSize:"
  * [kcm] Remove unused import
  * [kcm] Fix binding loop in "Add connection" list view
  * Port to singleton Units and Theme
  * Applet: delay model updates on expanded password field (kde#435430)
  * OpenConnect: don't present an empty form to the user
  * Fix bug with openfortivpn that do not support 2fa (kde#434940)
  * [applet] Remove broken call to closeSearch()
  * [applet] Manually bind width of list item
  * Fix "PAN GlobalProtect" selection when configuring OpenConnect
  * Raise minimum CMake version to 3.16
  * Make Configuration a proper singleton
  * Use versionless Qt cmake target
  * [applet] Make spacing for header items consistent
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- Changes since 5.21.4:
  * Forward openconnect usergroup (kde#435561)
  * Applet: delay model updates on expanded password field (kde#435430)
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- Changes since 5.21.3:
  * Fix bug with openfortivpn that do not support 2fa (kde#434940)
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- Changes since 5.21.2:
  * [applet] Remove broken call to closeSearch()
  * [applet] Manually bind width of list item
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * [applet] Make spacing for header items consistent
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Too many changes to list here
- Drop patches, now upstream:
  * 0001-Add-support-for-the-OpenVPN-parameter-compress.patch
* Fri Jan  8 2021 Andrés Barrantes Silman <andresbs@opensuse.org>
- Enables mobile components for Plasma Mobile
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- Changes since 5.20.4:
  * Fix password entry jumping to different networks with wifi
    scanning, by pausing the scan when appropriate
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- No code changes since 5.20.3
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- Changes since 5.20.2:
  * Do not show absurdedly high speeds on first update
* Wed Nov  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to support the compress parameter in .ovpn files (boo#1178258):
  * 0001-Add-support-for-the-OpenVPN-parameter-compress.patch
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- No code changes since 5.20.0
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Too many changes to list here
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Drop patches, now upstream:
  * 0001-WIP-applet-Fix-inline-password-field-component-not-w.patch
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- Changes since 5.19.3:
  * Make hotspot configuration dialog bigger
  * Remove (seemingly debug) warning statement from passworddialog
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- Changes since 5.19.1:
  * [applet] Remove styled text support from list items (kde#423020)
* Thu Jun 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Fix the inline password field (kde#423093):
  * 0001-WIP-applet-Fix-inline-password-field-component-not-w.patch
- Drop patches for Leap 42.3:
  * 0001-Revert-Show-correct-current-download-and-upload-spee.patch
  * 0001-Revert-Inform-about-missing-NetworkManager-VPN-plugi.patch
  * 0001-Revert-Use-NetworkManager-DeviceStatistics-instead-o.patch
  * 0001-Revert-Require-NM-1.4.0-and-newer.patch
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- Changes since 5.19.0:
  * openvpn: avoid enabling TCP if the remote has been set on another line
  * Testing AccessPoint::Privacy flag is not enough to check whether AP is secured (kde#422740)
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Too many changes to list here
- Drop patches, now upstream:
  * 0001-Use-system-color-scheme-from-Kirigami-instead-of-Pla.patch
  * 0002-KCM-restore-original-color.patch
* Wed May 13 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix appearance of the KCM (kde#418416):
  * 0001-Use-system-color-scheme-from-Kirigami-instead-of-Pla.patch
  * 0002-KCM-restore-original-color.patch
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- No code changes since 5.18.4.1
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- Changes since 5.18.3:
  * Openconnect: make sure the UI fits into the password dialog (kde#403480)
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Changes since 5.18.2:
  * [kded] Remove html tags from password dialog (kde#418625)
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- Changes since 5.18.1:
  * Fix build with missing includes
  * [kded] Set password dialog boxes to plaintext
  * [kded] Escape notifications
  * [kcm] Escape connection name in close dialog
  * KCM: Fix connection list background and padding
  * Fix ampersand and other characters in tooltip (kde#398225)
  * Make sure we change icon on NM connectivity change
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- Changes since 5.18.0:
  * Fix crash when asking for a modem unlock (kde#417545)
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- Changes since 5.17.90:
  * [Applet] Focus search field after showing it (kde#416482)
  * Do not emit signals from lambda slot and constructor
  * Do not hardcode icon sizes
  * Remove notification inhibitor lock
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Mon Jan 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Fix version in source URL
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90.4
  * New bugfix release
- Changes since 5.17.90:
  * Do not hardcode icon sizes
  * Remove notification inhibitor lock
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Too many changes to list here
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- Changes since 5.17.4:
  * Do not crash when changing advanced IPv4 configuration (kde#415856)
  * Port KCM menu away from PlasmaComponents (kde#414762)
  * Fortisslvpn: add option to ignore the password BUG: 414975 (kde#414975)
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- Changes since 5.17.3:
  * connect groupbox toggles to change signal
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- Changes since 5.17.0:
  * Wired connection: default to Full duplex when duplex is not set (kde#413211)
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Too many changes to list here
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- Changes since 5.16.4:
  * Add some missing includes.
  * Make "Network Disconnected" notification low priority
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- Changes since 5.16.3:
  * Airplane mode improvements (kde#399993,kde#400535,kde#405447)
* Thu Jul 18 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the kf5_makeinstall call. It cannot use brackets.
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- Changes since 5.16.2:
  * Change validator for Endpoint Address entry field (kde#408670)
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- Changes since 5.16.0:
  * Handle Esc properly when focus is in searchbox (kde#408290)
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- Changes since 5.15.90:
  * [CompactRepresentation] Glow on hover
  * Add missing includes
  * Fortissl VPN: fix crash when obtaining properties in the auth dialog (kde#407596)
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * Make tests to build
  * Add WireGuard at the end of the list of VPNs to make it correctly sorted
  * Add default value for parent in contructors of all validator classes
  * Update WireGuard to match NetworkManager 1.16 interface (kde#405501)
  * PasswordField: add option to hide AlwaysAsk mode
  * Added new option to use GlobalProtect with openconnect
  * Mark "Connection Activated" notifications as low priority
  * Port widget settings window to QQC2+Kirigami FormLayout
  * Add OTP support for openconnect VPN
  * Don't load the KSharedConfig instance on every read
  * No need to set height to implicitHeight (kde#399155)
  * OpenVPN: reneg-sec property doesn't need limitation (kde#404614)
  * Inform about missing NetworkManager VPN plugin (kde#405088)
  * Change entry of Endpoint UI (kde#403548)
  * send a signal over dbus when the wrong password is provided
  * [plasma-nm] Refresh wifi networks as fast as possible
  * Remove redundant DNS field (kde#403546)
  * Do not check NM version++
  * Do not check NM version
  * plasma-nm Connection Icon not showing correct icon when using a bridge (kde#397352)
  * Fix connections' context menus position and parent
  * Get rid of Q_FOREACH
  * We require NM 1.4.0+ so we can remove these conditions
  * Add a popup search bar to the plasma-nm applet (kde#344789,kde#394290)
  * [plasma-nm/applet] Use correct HIG-approved string for Configure... action
  * Configuration to never show the passwors dialog
  * [plasma-nm/applet] Add right-click context menu to directly customize a connection
- Add patch to fix build on Leap 42.3:
  * 0001-Revert-Inform-about-missing-NetworkManager-VPN-plugi.patch
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- Changes since 5.15.4:
  * Reject invalid keys
  * Reset model when there are new available connections (kde#406765)
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- Changes since 5.15.3:
  * Do not remove manually configured "route-metric" property from IPv4 and IPv6 setting (kde#406118)
  * Applet: fix size of the busy indicator (kde#405962)
  * OpenVPN: reneg-sec property doesn't need limitation (kde#404614)
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * [build] Search for kirigami as a runtime dependency
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Too many changes to list here
- Introduces wireguard support
- Refresh patches:
  * 0001-Revert-Show-correct-current-download-and-upload-spee.patch
  * 0001-Revert-Use-NetworkManager-DeviceStatistics-instead-o.patch
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Fix a wrong check in previous patch
  * Openconnect: do not reload dialog when group changes for Juniper protocol (kde#395157)
  * Revert "Openconnect: do not reload the auth dialog endlessly when group changes"
  * Notify that kcm changed only when validity has changed (kde#379756)
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * Openconnect: do not reload the auth dialog endlessly when group changes (kde#395157)
  * VPN plugins: fix broken layout when using password field
  * Do not request secrets for VPN connections all the time
  * SSH VPN: put content of the configuration into scroll area BUG: 401004 FIXED-IN: 5.14.4 (kde#401004)
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- Changes since 5.14.2:
  * Use appropriate icon in system tray settings BUG: 400587 FIXED-IN: 5.14.3 (kde#400587)
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- Changes since 5.14.1:
  * Show correct current download and upload speed
- Revert yet another commit for 42.3:
  * 0001-Revert-Show-correct-current-download-and-upload-spee.patch
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- Changes since 5.14.0:
  * openconnect: add missing dependency Qt5Xml
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- Changes since 5.13.90:
  * Fix ampersand and other characters in tooltip (kde#398225)
* Sun Sep 16 2018 wbauer@tmo.at
- Add 0001-Revert-Require-NM-1.4.0-and-newer.patch to make it build
  on Leap 42.3 which only has NetworkManager 1.0
- Add 0001-Revert-Use-NetworkManager-DeviceStatistics-instead-o.patch
  for Leap 42.3 to make speed graph work again with NM < 1.4.0
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * Make sure we change icon on NM connectivity change (boo#1108019)
  * Use QOverload to select overloaded functions
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Use NetworkManager::DeviceStatistics instead of Plasma data engine
  * Require NM 1.4.0 and newer
  * Unbreak SSH agent support for SSH VPN tunnels.
  * Parse protocol in port option
  * Port away from KLocale and KDELibs4Support
  * Update connection details only when necessary
  * Use more nullptr
  * Port from KStandardDirs to QStandardPaths
  * Use non-deprecated KDEInstallDirs variables
  * Use KF5_MIN_VERSION also for KF5ModemManagerQt
  * Find KF5NetworkManagerQt together with other KF5 modules
  * Fix label buddy in fortisslvpn auth widget
  * Cleanup used Qt & KF libraries a bit
  * Remove unneeded include
  * Use KF5Wallet include for KWallet, not the kdelibs4support one
  * Remove duplicated include
  * Use explicit
  * Use nullptr
  * Use override consistently
  * Remove unused entry X-KDE-DBus-ModuleName from the kded plugin metadata
  * Remove usage of dead QT_USE_FAST_CONCATENATION
  * Remove Qt module includes
  * Remove unneeded cmake macro includes
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Require KDE Frameworks 5.42 and Qt 5.9
  * Bump min cmake version to 3.0, move cmake_minimum_required to begin
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * Fix a text label in the password dialog
  * Add additional checks for device existence (kde#396957)
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jul  3 2018 bjorn.lie@gmail.com
- Add conditional for NetworkManager-openswan Requires: No longer
  available in Tumbleweed and newer.
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * Properly fix icon size for connection delegate BUG: 394580 (kde#394580)
  * Attempt to fix icon size for connection delegate BUG: 394580 (kde#394580)
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * Assign notification area category
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Remove unused code
  * Simplify connection item delegate
  * Use QtQuick's built-in HSV color features for cycling download color
  * Coding style and minor improvements
  * Unquote remote when importing OpenVPN connections (kde#393657)
  * Use ScrollView from QtQuickControls in the main connection view (kde#393794)
  * Check for device not being null
  * Require NM 1.0.0 and newer
  * use the bundled variant of installpackage
  * Adjust spacing between text and plotter line in Speed tab of nm applet
* Wed May  9 2018 fabian@ritter-vogt.de
- Add supplements to avoid hard requires (part of fix for boo#982962)
* Wed May  2 2018 wbauer@tmo.at
- Unconditionally provide the -vpnc subpackage again for now, vpnc
  is still in Tumbleweed and has been revived for Leap 15.0
- Activate proper Requires and Supplements for the -openswan,
  - l2tp, and -iodine subpackages, the corresponding NetworkManager
  packages are in Factory (and Leap) meanwhile
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Apr  3 2018 fabian@ritter-vogt.de
- Fix plasma-nm5-openconnect supplements
- Don't provide the -vpnc subpackage anymore on TW and Leap 15
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * Use ScrollView from QtQuickControls (kde#390846)
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * None
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Too many changes to list here
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * Do not set password field as readonly, it doesn't make sense
  * Disable password field when password is not needed (kde#386426)
  * Make sure we store password for all users when kwallet is diabled (kde#386343)
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * Do not load initially selected connection twice BUG: 379756 (kde#379756)
  * Fix focus in DNS servers and DNS domains dialogs BUG: 385839 (kde#385839)
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * Don't duplicate UI option for automatic speed detection (kde#383505)
  * Remove unused identity model
  * It makes sense to show VPN connections only when we are connected to internet
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * Drop the old legacy connection editor
  * Add option to allow managing virtual connections (kde#376664)
  * Summary: L2TP: pre-sharedkey should be mask
  * Add support for fortisslvpn
  * Openconnect: make sure the UI fits into the password dialog (kde#380399)
  * UI updates for NetworkManager-l2tp 1.2.6
  * Add missing file with UI for configuration
  * Allow to have wider password dialog while preffering minimum size (kde#380399)
  * Openconnect: make sure we accept the dialog (kde#380299)
  * Openconnect: Add option to select protocol
  * Properly pass specific vpn type when selecting new connection by double click
  * Openconnect (juniper): Properly make sure we are compatible with the rest of nm tools
  * Openconnect (juniper): Make sure we are compatible with the rest of nm tools (kde#380244)
  * Add option to disable unlocking modem on detection (kde#380150)
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Fri Aug  4 2017 fabian@ritter-vogt.de
- Don't use symlinks for %%fdupes, it's not allowed for kpackages
  (boo#1052119)
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * Openconnect: make sure the UI fits into the password dialog (kde#380399)
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * Restrict shared connections to permanent hardware address (kde#380379)
  * Allow to have wider password dialog while preffering minimum size (kde#380399)
  * Openconnect: make sure we accept the dialog (kde#380299)
  * Properly pass specific vpn type when selecting new connection by double click
  * Openconnect (juniper): Properly make sure we are compatible with the rest of nm tools
  * Openconnect (juniper): Make sure we are compatible with the rest of nm tools (kde#380244)
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * Workaround to fix PasswordDialog's focus. (kde#379279)
  * Remove option to set network type in gsm configuration (kde#379400)
  * Improve password dialogs
  * Fix minor typo
  * OpenVPN: don't require setting to be non-empty for advanced configuration
  * OpenVPN: add new properties (sync with NM) (kde#378648)
  * Simplify connection item delegate
  * OpenVPN: Remove previously configured secrets to avoid passing them back (kde#375170)
  * KCM: Do not use Plasma components as the colors are not consistent (kde#374905)
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * Missing include
  * Set auto-negotiate to true for newly created wired connections (kde#378554)
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * WiredSetting: Speed has to be set when auto-negotiation is off (kde#376018)
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Don't assume initialized if there are pending dbus replies
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * elide Network Manager KCM tabs
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * Fix crash caused by notifications use-after-free
  * Openconnect: cast QWidget to correct widget type used for password field
  * OpenVPN: Remove previously configured secrets to avoid passing them back
  * OpenVPN: Remove previously configured secrets to avoid passing them back
  * KCM: Do not use Plasma components as the colors are not consistent
  * Use KDE specific page for captive portal redirection
  * Some captive portals seems to have problem redirecting from https
  * Revert "Pass protocol type to openconnect"
  * Pass protocol type to openconnect
  * When importing an OpenVPN connection set default passwords to be stored in KWallet
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * See https://www.kde.org/announcements/plasma-5.8.5-5.8.95-changelog.php#plasma-nm
- Don't try to build openconnect support on 13.2
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Fri Aug 12 2016 hrvoje.senjan@gmail.com
- Adjust filelist for the plasmoid appdata, installed with KF > 5.25.0
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Sat Jul 23 2016 jengelh@inai.de
- Update descriptions
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Fri May 20 2016 alarrosa@suse.com
- The mobile-broadband-provider-info package is not required anymore,
  but recommended.
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Build the openconnect plugin on Leap
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Thu May 28 2015 tittiatcoke@gmail.com
- Add obsoletes for the old NetworkManager-kde4 package to
  enable a smooth upgrade path from older openSUSE releases
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Tue May 19 2015 hrvoje.senjan@gmail.com
- Drop pkgconfig(Qt5Concurrent), pkgconfig(Qt5Designer),
  pkgconfig(Qt5Declarative), pkgconfig(Qt5OpenGL),
  pkgconfig(Qt5Script), pkgconfig(Qt5ScriptTools),
  pkgconfig(Qt5Sql), pkgconfig(Qt5Svg), pkgconfig(Qt5Test),
  pkgconfig(Qt5WebKit), pkgconfig(Qt5WebKitWidgets) and
  pkgconfig(Qt5X11Extras) BuildRequires, no longer needed
* Sun May 17 2015 hrvoje.senjan@gmail.com
- Also obsolete plasma-nm subpackages for openSUSE > 13.2
* Tue May 12 2015 hrvoje.senjan@gmail.com
- Make sure we require NetworkManager
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Obsolete plasma-nm for openSUSE > 13.2
* Wed Apr 15 2015 hrvoje.senjan@gmail.com
- Don't build openconnect plugin on SLE
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Update required NetworkManager-devel version to 0.9.8.4
- Update required extra-cmake-modules version to 1.3.0
- Update required libKF5NetworkManagerQt-devel to 5.8.0
- Update required libKF5ModemManagerQt-devel to 5.9.0
- Add explicit pkgconfig(ModemManager) >= 1.0.0 BuildRequires
- Drop patches merged upstream:
  0001-Update-CMakeLists.txt-to-use-a-new-version-of-mm-qt.patch
  and 0002-Adapt-to-modemmanager-qt-API-changes.patch
* Sun Apr  5 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Update-CMakeLists.txt-to-use-a-new-version-of-mm-qt.patch
  and 0002-Adapt-to-modemmanager-qt-API-changes.patch
- Add explicit pkgconfig(ModemManager) BuildRequires
- Raise libKF5ModemManagerQt-devel BuildRequires to 5.8.0
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
- Drop 0001-Make-NM-to-store-Openconnect-secrets-into-KWallet.patch,
  merged upstream
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Drop patches merged upstream:
    0001-Adapt-to-libnm-qt-changes.patch
    0001-OpenVPN-Add-option-for-server-certificate-verificati.patch
    0001-Update-OpenConnect-support-for-library-version-5.patch
    0002-Update-OpenConnect-storage-of-manually-accepted-serv.patch
- Fix supplements markings in spec
- Added 0001-Make-NM-to-store-Openconnect-secrets-into-KWallet.patch
  (kde#309931, kde#334474)
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Added 0001-Adapt-to-libnm-qt-changes.patch from upstream
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Mon Dec  8 2014 hrvoje.senjan@gmail.com
- Added 0001-Update-OpenConnect-support-for-library-version-5.patch
  and 0002-Update-OpenConnect-storage-of-manually-accepted-serv.patch
  from upstream to support building/working with openconnect version 7
* Sat Nov 29 2014 hrvoje.senjan@gmail.com
- Added 0001-OpenVPN-Add-option-for-server-certificate-verificati.patch,
  kde#341069
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Properly initialize new OpenVPN connections, kde#340190
  * Fix crash when trying to set operator name for uninitialized
    GsmInterface, kde#340364
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
- Drop plasma-nm-5.1.0.1-openvpn.patch, merged upstream
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Tue Oct 21 2014 tchvatal@suse.com
- Fix obsoletes/provides warning
- Cleanup with spec-cleaner
- Fix plasma-nm5-openvpn loosing its configuration on first setup:
  * plasma-nm-5.1.0.1-openvpn.patch
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Fixed kde#339223
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Fri Sep 12 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95~git20140912 (rfe4e4ba):
  * Applet improvements
  * Less usage of kdelibs4support libraries
  * Fixed bugs include kde#338146, and kde#338513, kde#337956
- Require kwalletd5
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Fri Jul 11 2014 cdenicolo@suse.com
- license update: (LGPL-2.1 or LGPL-3.0) and (GPL-2.0 or GPL-3.0)
  package is kde dual licensed, also GPL.
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Activate plasma-nm5 package
